@@ -1,14 +1,9 @@
 require 'mongoid'
 
 Mongoid.configure do |config|
-  name = 'database_cleaner_test'
-  config.connect_to(name)
+  config.master = Mongo::Connection.new.db('database_cleaner_test')
 end
 
-
-#::MongoMapper.connection = Mongo::Connection.new('127.0.0.1')
-#::MongoMapper.database = 'database_cleaner_test'
-
 class MongoidWidget
   include Mongoid::Document
   field :id, :type => Integer
