@@ -2,7 +2,11 @@ $LOAD_PATH.unshift(File.expand_path(File.dirname(__FILE__))) unless $LOAD_PATH.i
 require 'database_cleaner/configuration'
 
 module DatabaseCleaner
-  def self.can_detect_orm?
-    DatabaseCleaner::Base.autodetect_orm
+  class << self
+    attr_accessor :allow_remote_database_url, :allow_production
+
+    def can_detect_orm?
+      DatabaseCleaner::Base.autodetect_orm
+    end
   end
 end
