@@ -57,6 +57,22 @@ module DatabaseCleaner
                               end
       end
 
+      def self.migration_table_name
+        if ::ActiveRecord::VERSION::MAJOR < 5
+          ::ActiveRecord::Migrator.schema_migrations_table_name
+        else
+          ::ActiveRecord::SchemaMigration.table_name
+        end
+      end
+
+      def self.exclusion_condition(column_name)
+        result = " #{column_name} <> '#{::DatabaseCleaner::ActiveRecord::Base.migration_table_name}' "
+        if ::ActiveRecord::VERSION::MAJOR >= 5
+          result += " AND #{column_name} <> '#{::ActiveRecord::Base.internal_metadata_table_name}' "
+        end
+        result
+      end
+
       private
 
       def lookup_from_connection_pool
@@ -69,8 +85,8 @@ module DatabaseCleaner
 
       def establish_connection
         ::ActiveRecord::Base.establish_connection(connection_hash)
+        ::ActiveRecord::Base
       end
-
     end
   end
 end
