@@ -54,11 +54,33 @@ module DatabaseCleaner::ActiveRecord
 
     def tables_with_new_rows(connection)
       @db_name ||= connection.instance_variable_get('@config')[:database]
-      result = connection.exec_query("SELECT table_name FROM information_schema.tables WHERE table_schema = '#{@db_name}' AND table_rows > 0")
-      result.map{ |row| row['table_name'] } - ['schema_migrations']
+      stats = table_stats_query(connection, @db_name)
+      if stats != ''
+        connection.exec_query(stats).inject([]) {|all, stat| all << stat['table_name'] if stat['exact_row_count'] > 0; all }
+      else
+        []
+      end
+    end
+
+    def table_stats_query(connection, db_name)
+      if @cache_tables && !@table_stats_query.nil?
+        return @table_stats_query
+      else
+        tables = connection.select_values(<<-SQL)
+          SELECT table_name
+          FROM information_schema.tables
+          WHERE table_schema = '#{db_name}'
+          AND #{::DatabaseCleaner::ActiveRecord::Base.exclusion_condition('table_name')};
+        SQL
+        queries = tables.map do |table|
+          "SELECT #{connection.quote(table)} AS table_name, COUNT(*) AS exact_row_count FROM #{connection.quote_table_name(table)}"
+        end
+        @table_stats_query = queries.join(' UNION ')
+      end
     end
 
     def information_schema_exists? connection
+      return false unless connection.is_a? ActiveRecord::ConnectionAdapters::Mysql2Adapter
       @information_schema_exists ||=
         begin
           connection.execute("SELECT 1 FROM information_schema.tables")
