@@ -1,6 +1,13 @@
 require 'database_cleaner/null_strategy'
+require 'database_cleaner/safeguard'
 module DatabaseCleaner
   class Base
+    include Comparable
+
+    def <=>(other)
+      (self.orm <=> other.orm) == 0 ? self.db <=> other.db : self.orm <=> other.orm
+    end
+
     def initialize(desired_orm = nil,opts = {})
       if [:autodetect, nil, "autodetect"].include?(desired_orm)
         autodetect
@@ -9,6 +16,7 @@ module DatabaseCleaner
       end
       self.db = opts[:connection] || opts[:model] if opts.has_key?(:connection) || opts.has_key?(:model)
       set_default_orm_strategy
+      Safeguard.new.run
     end
 
     def db=(desired_db)
@@ -96,11 +104,6 @@ module DatabaseCleaner
       !!@autodetected
     end
 
-    #TODO make strategies directly comparable
-    def ==(other)
-      self.orm == other.orm && self.db == other.db
-    end
-
     def autodetect_orm
       if defined? ::ActiveRecord
         :active_record
