@@ -22,10 +22,16 @@ module DatabaseCleaner
       private
 
       def connection
-        @connection ||= url == :default ? ::Redis.connect : ::Redis.connect(:url => url)
+        @connection ||= begin
+          if url == :default
+            ::Redis.new
+          elsif db.is_a?(::Redis) # pass directly the connection
+            db
+          else
+            ::Redis.new(:url => url)
+          end
+        end
       end
-
     end
   end
 end
-
