@@ -1,4 +1,5 @@
 require 'spec_helper'
+require 'redis'
 require 'database_cleaner/redis/base'
 require 'database_cleaner/shared_strategy'
 
@@ -18,10 +19,20 @@ module DatabaseCleaner
       it { should respond_to(:db) }
       it { should respond_to(:db=) }
 
-      it "should store my describe db" do
-        url = 'redis://localhost:6379/2'
-        subject.db = 'redis://localhost:6379/2'
-        subject.db.should eq url
+      context "when passing url" do
+        it "should store my describe db" do
+          url = 'redis://localhost:6379/2'
+          subject.db = 'redis://localhost:6379/2'
+          subject.db.should eq url
+        end
+      end
+
+      context "when passing connection" do
+        it "should store my describe db" do
+          connection = ::Redis.new :url => 'redis://localhost:6379/2'
+          subject.db = connection
+          subject.db.should eq connection
+        end
       end
 
       it "should default to :default" do
