@@ -7,25 +7,25 @@ module MySQLHelper
   # require 'logger'
   # ActiveRecord::Base.logger = Logger.new(STDERR)
 
-  def config
+  def default_config
     db_config['mysql']
   end
 
   def create_db
-    establish_connection(config.merge(:database => nil))
+    establish_connection(default_config.merge(:database => nil))
 
-    ActiveRecord::Base.connection.drop_database config['database'] rescue nil
-    ActiveRecord::Base.connection.create_database config['database']
+    ActiveRecord::Base.connection.drop_database default_config['database'] rescue nil
+    ActiveRecord::Base.connection.create_database default_config['database']
   end
 
-  def establish_connection config = config
+  def establish_connection(config = default_config)
     ActiveRecord::Base.establish_connection config
   end
 
   def active_record_mysql_setup
     create_db
     establish_connection
-    load_schema
+    active_record_load_schema
   end
 
   def active_record_mysql_connection
